from blue_options import NAME, VERSION, DESCRIPTION, ICON
from blueness.argparse.generic import main

success, message = main(__file__, NAME, VERSION, DESCRIPTION, ICON)
if not success:
    print(f"❗️ {message}")



from blue_options import NAME, VERSION, DESCRIPTION, REPO_NAME
from blueness.pypi import setup


setup(
    filename=__file__,
    repo_name=REPO_NAME,
    name=NAME,
    version=VERSION,
    description=DESCRIPTION,
    packages=[NAME],
    include_package_data=True,
    package_data={
        NAME: [
            ".bash/*.sh",
        ],
    },
)
